package com.ruoyi.system.kernel;

import com.ruoyi.common.core.web.domain.AjaxResult;
import java.util.concurrent.TimeUnit;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.common.redis.service.RedisService;
import org.springframework.stereotype.Service;

@Service
public class SslCountLimit
{
    @Autowired
    private RedisService redisService;
    
    public void addCount(final String domain, final String ip) {
        final String hourKey = "ssl_hour_" + domain + "_" + ip;
        final String dayKey = "ssl_date_" + domain + "_" + ip;
        if (this.redisService.hasKey(hourKey)) {
            this.redisService.increment(hourKey);
        }
        else {
            this.redisService.incrementExpire(hourKey, 1L, TimeUnit.HOURS);
        }
        if (this.redisService.hasKey(dayKey)) {
            this.redisService.increment(dayKey);
        }
        else {
            this.redisService.incrementExpire(dayKey, 24L, TimeUnit.HOURS);
        }
    }
    
    public AjaxResult validCount(final String domain, final String ip) {
        final String hourKey = "ssl_hour_" + domain + "_" + ip;
        final String dayKey = "ssl_date_" + domain + "_" + ip;
        if (this.redisService.hasKey(hourKey)) {
            final Integer num = (Integer)this.redisService.getCacheObject(hourKey);
            if (num >= 3) {
                return AjaxResult.error("一个域名1小时内只能申请3次免费证书，请稍后再试");
            }
        }
        if (this.redisService.hasKey(dayKey)) {
            final Integer num = (Integer)this.redisService.getCacheObject(dayKey);
            if (num >= 5) {
                return AjaxResult.error("一个域名24小时内只能申请5次免费证书，请稍后再试");
            }
        }
        return AjaxResult.success();
    }
}
